@@ -2,7 +2,7 @@
     This file is part of Akonadi Contact.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -35,7 +35,7 @@ class CustomFieldEditorWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit CustomFieldEditorWidget(QWidget *parent = Q_NULLPTR);
+    explicit CustomFieldEditorWidget(QWidget *parent = nullptr);
     ~CustomFieldEditorWidget();
     void setReadOnly(bool readOnly);
 
